@@ -9,17 +9,20 @@ from .dvs.model_convtiny_handy import (convtiny_dvs_handy,
 from .cifar10.model_ds_cnn import ds_cnn_cifar10, ds_cnn_cifar10_pretrained
 from .cifar10.model_vgg import vgg_cifar10, vgg_cifar10_pretrained
 from .imagenet.model_mobilenet import (mobilenet_imagenet,
-                                       mobilenet_imagenet_pretrained,
-                                       mobilenet_cats_vs_dogs_pretrained,
-                                       mobilenet_imagenette_pretrained,
-                                       mobilenet_faceidentification_pretrained,
-                                       mobilenet_faceverification_pretrained)
-from .imagenet.model_vgg import (vgg_imagenet, vgg_imagenet_pretrained,
-                                 vgg_melanoma_pretrained, vgg_odir5k_pretrained,
-                                 vgg_retinal_oct_pretrained, vgg_ecg_pretrained)
-from .imagenet.model_mobilenet_edge import (
-    mobilenet_edge_imagenet, mobilenet_edge_imagenet_pretrained,
-    mobilenet_faceidentification_edge_pretrained)
+                                       mobilenet_imagenet_pretrained)
+from .imagenet.model_vgg import (vgg_imagenet, vgg_imagenet_pretrained)
+from .imagenet.model_mobilenet_edge import (mobilenet_edge_imagenet,
+                                            mobilenet_edge_imagenet_pretrained)
+from .imagenet.model_akidanet import (
+    akidanet_imagenet, akidanet_imagenet_pretrained,
+    akidanet_cats_vs_dogs_pretrained, akidanet_imagenette_pretrained,
+    akidanet_faceidentification_pretrained,
+    akidanet_faceverification_pretrained, akidanet_melanoma_pretrained,
+    akidanet_odir5k_pretrained, akidanet_retinal_oct_pretrained,
+    akidanet_ecg_pretrained, akidanet_plantvillage_pretrained)
+from .imagenet.model_akidanet_edge import (
+    akidanet_edge_imagenet, akidanet_edge_imagenet_pretrained,
+    akidanet_faceidentification_edge_pretrained)
 from .kws.model_ds_cnn import ds_cnn_kws, ds_cnn_kws_pretrained
 from .modelnet40.model_pointnet_plus import (pointnet_plus_modelnet40,
                                              pointnet_plus_modelnet40_pretrained
