@@ -18,10 +18,9 @@
 DS-CNN model definition for CIFAR10 classification.
 """
 
-from tensorflow.keras.layers import Input
-from tensorflow.keras.layers.experimental.preprocessing import Rescaling
-from tensorflow.keras import Model
-from tensorflow.keras.utils import get_file
+from keras.layers import Input, Rescaling
+from keras import Model
+from keras.utils.data_utils import get_file
 
 from cnn2snn import load_quantized_model, quantize
 
@@ -69,7 +68,7 @@ def ds_cnn_cifar10(input_shape=(32, 32, 3),
             the scale factor is an integer used as a divider.
 
     Returns:
-        tf.keras.Model: a Keras model for DS-CNN/CIFAR-10
+        keras.Model: a Keras model for DS-CNN/CIFAR-10
     """
 
     # Overrides input weight quantization if None
@@ -202,7 +201,7 @@ def ds_cnn_cifar10_pretrained():
     CIFAR10 dataset.
 
     Returns:
-        tf.keras.Model: a Keras Model instance.
+        keras.Model: a Keras Model instance.
 
     """
     model_name = 'ds_cnn_cifar10_iq4_wq4_aq4.h5'
