@@ -31,6 +31,8 @@ from .kws.model_ds_cnn import ds_cnn_kws
 from .modelnet40.model_pointnet_plus import pointnet_plus_modelnet40
 from .imagenet.model_mobilenet import mobilenet_imagenet
 from .imagenet.model_vgg import vgg_imagenet
+from .imagenet.model_akidanet import akidanet_imagenet
+from .imagenet.model_akidanet_edge import akidanet_edge_imagenet
 from .imagenet.model_mobilenet_edge import mobilenet_edge_imagenet
 from .detection.model_yolo import yolo_base
 from .dvs.model_convtiny_handy import convtiny_dvs_handy
@@ -121,6 +123,37 @@ def main():
                             type=int,
                             default=1000,
                             help="The number of edge learning classes")
+    an_parser = csp.add_parser("akidanet_imagenet", help="An AkidaNet model")
+    an_parser.add_argument("-i",
+                           "--image_size",
+                           type=int,
+                           default=224,
+                           choices=image_sizes,
+                           help="The square input image size")
+    an_parser.add_argument("-a",
+                           "--alpha",
+                           type=float,
+                           default=1.0,
+                           help="The width of the model")
+    an_parser.add_argument("-c",
+                           "--classes",
+                           type=int,
+                           default=1000,
+                           help="The number of classes")
+    ane_parser = csp.add_parser("akidanet_edge_imagenet",
+                                help="An AkidaNet model modified for akida \
+                                edge learning")
+    ane_parser.add_argument("-bm",
+                            "--base_model",
+                            type=str,
+                            required=True,
+                            help="The base AkidaNet model to use for edge \
+                            adaptation.")
+    ane_parser.add_argument("-c",
+                            "--classes",
+                            type=int,
+                            default=1000,
+                            help="The number of edge learning classes")
     pnet_parser = csp.add_parser("pointnet_plus_modelnet40",
                                  help="A PointNet++ model for Akida")
     pnet_parser.add_argument("-c",
@@ -186,6 +219,14 @@ def main():
         elif args.model == "mobilenet_imagenet_edge":
             model = mobilenet_edge_imagenet(base_model=args.base_model,
                                             classes=args.classes)
+        elif args.model == "akidanet_imagenet":
+            input_shape = (args.image_size, args.image_size, 3)
+            model = akidanet_imagenet(input_shape,
+                                      alpha=args.alpha,
+                                      classes=args.classes)
+        elif args.model == "akidanet_edge_imagenet":
+            model = akidanet_edge_imagenet(base_model=args.base_model,
+                                           classes=args.classes)
         elif args.model == "yolo_base":
             model = yolo_base(classes=args.classes,
                               nb_box=args.number_anchors,
