@@ -20,8 +20,8 @@ TSE/MLP model definition for CSE-CIC-IDS-2018 classification.
 
 import os
 
-from tensorflow.keras import Model
-from tensorflow.keras.utils import get_file
+from keras import Model
+from keras.utils.data_utils import get_file
 
 from cnn2snn import load_quantized_model, quantize
 
@@ -64,7 +64,7 @@ def tse_mlp_cse2018(numerical_columns=None,
             * '2' through '8' implements n-bit weights where n is from 2-8 bits.
 
     Returns:
-        tf.keras.Model: a Keras model for tabular data on CSE-CIC-IDS-2018
+        keras.Model: a Keras model for tabular data on CSE-CIC-IDS-2018
     """
     # Overrides input weight quantization if None
     if input_weight_quantization is None:
@@ -104,7 +104,7 @@ def tse_mlp_cse2018_pretrained():
     CSE-CIC-IDS-2018 dataset.
 
     Returns:
-        tf.keras.Model: a Keras Model instance.
+        keras.Model: a Keras Model instance.
 
     """
     model_name = 'tse_mlp_cse2018_iq0_wq2_aq4.tar.gz'
