@@ -185,8 +185,8 @@ class BatchGenerator(Sequence):
                         y_batch[instance_count, grid_y, grid_x, best_anchor,
                                 5 + obj_indx] = 1
 
-            # assign normalized input image to x_batch
-            x_batch[instance_count] = (img - 127.5) / 127.5
+            # assign input image to x_batch
+            x_batch[instance_count] = img
 
             # increase instance counter in current batch
             instance_count += 1
