@@ -18,18 +18,18 @@
 Module used to compute mAP scores for YOLO classification.
 """
 
-import tensorflow as tf
+import keras
 import numpy as np
 
 from .processing import load_image, preprocess_image, decode_output
 
 
-class MapEvaluation(tf.keras.callbacks.Callback):
+class MapEvaluation(keras.callbacks.Callback):
     """ Evaluate a given dataset using a given model.
         Code originally from https://github.com/fizyr/keras-retinanet.
 
         Args:
-            model (tf.keras.Model): model to evaluate.
+            model (keras.Model): model to evaluate.
             val_data (dict): dictionary containing validation data as obtained
              using `preprocess_widerface.py` module
             labels (list): list of labels as strings
