@@ -28,15 +28,13 @@ from keras.utils.data_utils import get_file
 from cnn2snn import load_quantized_model, quantize
 
 from ..layer_blocks import separable_conv_block
-from ..imagenet.model_mobilenet import mobilenet_imagenet
+from ..imagenet.model_akidanet import akidanet_imagenet
 
 
 def yolo_base(input_shape=(224, 224, 3),
               classes=1,
               nb_box=5,
               alpha=1.0,
-              dropout=1e-3,
-              use_stride2=False,
               weight_quantization=0,
               activ_quantization=0,
               input_weight_quantization=None,
@@ -48,9 +46,6 @@ def yolo_base(input_shape=(224, 224, 3),
         classes (int): number of classes to classify images into
         nb_box (int): number of anchors boxes to use
         alpha (float): controls the width of the model
-        dropout (float): dropout rate
-        use_stride2 (bool): optional, replace max pooling operations by stride 2
-            convolutions in layers separable 2, 4, 6 and 12.
         weight_quantization (int): sets all weights in the model to have
             a particular quantization bitwidth except for the weights in the
             first layer.
@@ -79,13 +74,11 @@ def yolo_base(input_shape=(224, 224, 3),
     if input_weight_quantization is None:
         input_weight_quantization = weight_quantization
 
-    # Create a MobileNet network without top layers
-    base_model = mobilenet_imagenet(
+    # Create an AkidaNet network without top layers
+    base_model = akidanet_imagenet(
         input_shape=input_shape,
         alpha=alpha,
-        dropout=dropout,
         include_top=False,
-        use_stride2=use_stride2,
         weight_quantization=weight_quantization,
         activ_quantization=activ_quantization,
         input_weight_quantization=input_weight_quantization,
@@ -172,8 +165,8 @@ def yolo_widerface_pretrained():
     with open(anchors_path, 'rb') as handle:
         anchors = pickle.load(handle)
 
-    model_name = 'yolo_widerface_iq8_wq4_aq4.h5'
-    file_hash = 'ac7da503de7753326a9bca35295f576aabc29d4916250385252646df1430eb94'
+    model_name = 'yolo_akidanet_widerface_iq8_wq4_aq4.h5'
+    file_hash = '4effe9b2622ef3de2763f869f14d4d18b82f1bb6b69ba4c601aaa0a424f77864'
     model_path = get_file(fname=model_name,
                           origin='http://data.brainchip.com/models/yolo/' +
                           model_name,
@@ -201,8 +194,8 @@ def yolo_voc_pretrained():
     with open(anchors_path, 'rb') as handle:
         anchors = pickle.load(handle)
 
-    model_name = 'yolo_voc_iq8_wq4_aq4.h5'
-    file_hash = 'aaeb2900b6c5e66b2dbddb307dee2fd813a06f792cad8a60d001dff32097a473'
+    model_name = 'yolo_akidanet_voc_iq8_wq4_aq4.h5'
+    file_hash = '095861adc0e351ef06ab642c0ef8d651faf6a9f23d8277f96d2b01e1899f9c56'
     model_path = get_file(fname=model_name,
                           origin='http://data.brainchip.com/models/yolo/' +
                           model_name,
