@@ -21,7 +21,7 @@ This module defines a custom loss function for YOLO training.
 import numpy as np
 import tensorflow as tf
 
-from tensorflow.keras import backend as K
+from keras import backend as K
 
 EPSILON = 1e-7
 
