@@ -22,8 +22,8 @@ import os
 import argparse
 import numpy as np
 
-import tensorflow as tf
-from tensorflow.keras.utils import get_file
+from keras.utils.data_utils import get_file
+from keras.utils.np_utils import to_categorical
 
 from cnn2snn import load_quantized_model, convert
 
@@ -115,7 +115,7 @@ def get_data(dataset):
     x_test_ev, y_test = test_data.get_random_samples(
         class_list=class_list, samples_per_trial=sample_repeats)
     x_test = test_data.samples_evs2images(x_test_ev)
-    y_test = tf.keras.utils.to_categorical(y_test)
+    y_test = to_categorical(y_test)
 
     return train_data, x_test, y_test, class_list, sample_repeats
 
@@ -125,7 +125,7 @@ def train_model(model, train_set, test_set, class_list, sample_repeats,
     """ Trains the model.
 
     Args:
-        model (tf.keras.Model): the model to train
+        model (keras.Model): the model to train
         train_set (DVS_DataGenerator): train data generator
         test_set (tuple): test data and test labels as np.arrays
         class_list (list): classes selected for training
@@ -151,7 +151,7 @@ def train_model(model, train_set, test_set, class_list, sample_repeats,
         print('Epoch: ' + str(j))
         x_train_ev, y_train = train_set.get_random_samples(
             class_list=class_list, samples_per_trial=sample_repeats)
-        y_train = tf.keras.utils.to_categorical(y_train)
+        y_train = to_categorical(y_train)
 
         augmentation_repeats = 4
         for _ in range(augmentation_repeats):
