@@ -361,8 +361,9 @@ def prune_model(model,
         pruning_rates = [0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9]
 
     # Start by creating a copy of the model where batchnorm is folded
-    pruned_model = cnn2snn.utils.invert_batchnorm_pooling(model)
-    pruned_model = cnn2snn.utils.fold_batch_norms(pruned_model)
+    pruned_model = cnn2snn.transforms.sequentialize(model)
+    pruned_model = cnn2snn.transforms.invert_batchnorm_pooling(pruned_model)
+    pruned_model = cnn2snn.transforms.fold_batchnorm(pruned_model)
 
     # Get the list of prunable layers
     layers_to_prune = prunable_layers_policy(pruned_model)
