@@ -410,90 +410,3 @@ def mobilenet_imagenet_pretrained(alpha=1.0):
                           file_hash=file_hash,
                           cache_subdir='models')
     return load_quantized_model(model_path)
-
-
-def mobilenet_cats_vs_dogs_pretrained():
-    """
-    Helper method to retrieve a `mobilenet_imagenet` model that was trained on
-    Cats vs.Dogs dataset.
-
-    Returns:
-        keras.Model: a Keras Model instance.
-
-    """
-    model_name = 'mobilenet_cats_vs_dogs_iq8_wq4_aq4.h5'
-    file_hash = 'd65eb369844d6fa4ce5cee85c41ef3a662620d1a05b838df94c8d173b8f92b2c'
-    model_path = get_file(fname=model_name,
-                          origin=BASE_WEIGHT_PATH + model_name,
-                          file_hash=file_hash,
-                          cache_subdir='models')
-    return load_quantized_model(model_path)
-
-
-def mobilenet_imagenette_pretrained(alpha=1.0):
-    """
-    Helper method to retrieve a `mobilenet_imagenet` model that was trained on
-    Imagenette dataset.
-
-    Args:
-        alpha (float): width of the model.
-
-    Returns:
-        keras.Model: a Keras Model instance.
-
-    """
-    if alpha == 1.0:
-        model_name = 'mobilenet_imagenette_224_iq8_wq4_aq4.h5'
-        file_hash = '9e5f7294c2462fadee74499ac463c734acff571796ea1313e4e3eb6f93a4b090'
-    elif alpha == 0.5:
-        model_name = 'mobilenet_imagenette_224_alpha_50_iq8_wq4_aq4.h5'
-        file_hash = '0fcf9a1bd6a82042bf27b70fd337f38f2557fdbe3eb33ced76f6ce2c8bb6a710'
-    elif alpha == 0.25:
-        model_name = 'mobilenet_imagenette_224_alpha_25_iq8_wq4_aq4.h5'
-        file_hash = 'b0dbd0d87b7e496afdd62400760fe1cccecebb18a4b2b8db1edb6eb65a31beb8'
-    else:
-        raise ValueError(
-            f"Requested model with alpha={alpha} is not available.")
-
-    model_path = get_file(fname=model_name,
-                          origin=BASE_WEIGHT_PATH + model_name,
-                          file_hash=file_hash,
-                          cache_subdir='models')
-    return load_quantized_model(model_path)
-
-
-def mobilenet_faceidentification_pretrained():
-    """
-    Helper method to retrieve a `mobilenet_imagenet` model that was trained on
-    CASIA Webface dataset and that performs face identification.
-
-    Returns:
-        keras.Model: a Keras Model instance.
-
-    """
-    model_name = 'mobilenet_faceidentification_iq8_wq4_aq4.h5'
-    file_hash = 'd12f1dbd40267b483056728252eb56f578403071dcd472e39143319d6c84096c'
-    model_path = get_file(fname=model_name,
-                          origin=BASE_WEIGHT_PATH + model_name,
-                          file_hash=file_hash,
-                          cache_subdir='models')
-    return load_quantized_model(model_path)
-
-
-def mobilenet_faceverification_pretrained():
-    """
-    Helper method to retrieve a `mobilenet_imagenet` model that was trained on
-    CASIA Webface dataset and optimized with ArcFace that can perform face
-    verification on LFW.
-
-    Returns:
-        keras.Model: a Keras Model instance.
-
-    """
-    model_name = 'mobilenet_faceverification_iq8_wq4_aq4.h5'
-    file_hash = 'ee54055f6baa38339c9f45632a0ef37c8b617fe81b9e68b709845b5d1a711919'
-    model_path = get_file(fname=model_name,
-                          origin=BASE_WEIGHT_PATH + model_name,
-                          file_hash=file_hash,
-                          cache_subdir='models')
-    return load_quantized_model(model_path)
