@@ -108,21 +108,3 @@ def mobilenet_edge_imagenet_pretrained():
                           file_hash=file_hash,
                           cache_subdir='models')
     return load_quantized_model(model_path)
-
-
-def mobilenet_faceidentification_edge_pretrained():
-    """
-    Helper method to retrieve a `mobilenet_edge_imagenet` model that was trained
-    on CASIA Webface dataset and that performs face identification.
-
-    Returns:
-        keras.Model: a Keras Model instance.
-
-    """
-    model_name = 'mobilenet_faceidentification_edge_iq8_wq4_aq4.h5'
-    file_hash = '62958a630dbcaa79ec12f0071870788231cb96f27e5d7c86e37927696c04a4a8'
-    model_path = get_file(fname=model_name,
-                          origin=BASE_WEIGHT_PATH + model_name,
-                          file_hash=file_hash,
-                          cache_subdir='models')
-    return load_quantized_model(model_path)
