@@ -21,7 +21,8 @@ KWS model training script.
 import os
 import pickle
 
-from tensorflow.keras.utils import to_categorical, get_file
+from keras.utils.np_utils import to_categorical
+from keras.utils.data_utils import get_file
 
 from cnn2snn import load_quantized_model, quantize_layer, convert
 
@@ -53,7 +54,7 @@ def train_model(model, x_train, y_train, x_val, y_val, batch_size, epochs):
     """ Trains the model.
 
     Args:
-         model (tf.keras.Model): the model to train
+        model (keras.Model): the model to train
         x_train (numpy.ndarray): train data
         y_train (numpy.ndarray): train labels
         x_val (numpy.ndarray): validation data
@@ -108,7 +109,7 @@ def main():
 
     # If specified, change the last layer activation bitwidth
     if "last_activ_quantization" in args and args.last_activ_quantization:
-        model = quantize_layer(model, 'separable_6_relu',
+        model = quantize_layer(model, 'separable_4_relu',
                                args.last_activ_quantization)
 
     # Compile model
