@@ -18,12 +18,11 @@
 DS-CNN model definition for KWS classification.
 """
 
-from tensorflow.keras import Model
-from tensorflow.keras.layers import Input, Reshape, Activation, Flatten
-from tensorflow.keras.layers.experimental.preprocessing import Rescaling
-from tensorflow.keras.utils import get_file
+from keras import Model
+from keras.layers import (Input, Reshape, Activation, Flatten, Rescaling)
+from keras.utils.data_utils import get_file
 
-from cnn2snn import load_quantized_model, quantize, quantize_layer
+from cnn2snn import load_quantized_model, quantize
 
 from ..layer_blocks import conv_block, separable_conv_block, dense_block
 
@@ -36,7 +35,6 @@ def ds_cnn_kws(input_shape=(49, 10, 1),
                weight_quantization=0,
                activ_quantization=0,
                input_weight_quantization=None,
-               last_layer_activ_quantization=None,
                input_scaling=(255, 0)):
     """Instantiates a MobileNet-like model for the "Keyword Spotting" example.
 
@@ -71,24 +69,16 @@ def ds_cnn_kws(input_shape=(49, 10, 1),
             * 'None' implements the same bitwidth as the other weights.
             * '0' implements floating point 32-bit weights.
             * '2' through '8' implements n-bit weights where n is from 2-8 bits.
-        last_layer_activ_quantization (int): sets activation quantization in the
-            layer before the last. Defaults to activ_quantization value.
-
-            * 'None' implements the same bitwidth as the other activations.
-            * '0' implements floating point 32-bit activations.
-            * '1' through '8' implements n-bit weights where n is from 2-8 bits.
         input_scaling (tuple, optional): scale factor and offset to apply to
             inputs. Defaults to (255, 0). Note that following Akida convention,
             the scale factor is an integer used as a divider.
 
     Returns:
-        tf.keras.Model: a Keras model for MobileNet/KWS
+        keras.Model: a Keras model for MobileNet/KWS
     """
     # Overrides input weight quantization if None
     if input_weight_quantization is None:
         input_weight_quantization = weight_quantization
-    if last_layer_activ_quantization is None:
-        last_layer_activ_quantization = activ_quantization
 
     if include_top and not classes:
         raise ValueError("If 'include_top' is True, 'classes' must be set.")
@@ -102,7 +92,7 @@ def ds_cnn_kws(input_shape=(49, 10, 1),
         x = Rescaling(1. / scale, offset)(img_input)
 
     x = conv_block(x,
-                   filters=32,
+                   filters=64,
                    kernel_size=(5, 5),
                    padding='same',
                    strides=(2, 2),
@@ -140,33 +130,17 @@ def ds_cnn_kws(input_shape=(49, 10, 1),
                              padding='same',
                              use_bias=False,
                              name='separable_4',
-                             add_batchnorm=True)
-
-    x = separable_conv_block(x,
-                             filters=64,
-                             kernel_size=(3, 3),
-                             padding='same',
-                             use_bias=False,
-                             name='separable_5',
                              pooling='global_avg',
                              add_batchnorm=True)
 
     shape = (1, 1, int(64))
     x = Reshape(shape, name='reshape_1')(x)
 
-    x = separable_conv_block(x,
-                             filters=256,
-                             kernel_size=(3, 3),
-                             padding='same',
-                             use_bias=False,
-                             name='separable_6',
-                             add_batchnorm=True)
-
     if include_top:
         x = Flatten()(x)
         x = dense_block(x,
                         units=classes,
-                        name='dense_7',
+                        name='dense_5',
                         use_bias=True,
                         add_activation=False)
         act_function = 'softmax' if classes > 1 else 'sigmoid'
@@ -182,12 +156,6 @@ def ds_cnn_kws(input_shape=(49, 10, 1),
                          weight_quantization=weight_quantization,
                          activ_quantization=activ_quantization,
                          input_weight_quantization=input_weight_quantization)
-
-    # Change the last layer activation bitwidth
-    if last_layer_activ_quantization != activ_quantization:
-        model = quantize_layer(model, 'separable_6_relu',
-                               last_layer_activ_quantization)
-
     return model
 
 
@@ -197,11 +165,11 @@ def ds_cnn_kws_pretrained():
     KWS dataset.
 
     Returns:
-        tf.keras.Model: a Keras Model instance.
+        keras.Model: a Keras Model instance.
 
     """
     model_name = 'ds_cnn_kws_iq8_wq4_aq4_laq1.h5'
-    file_hash = 'cd56ca58ee1330bee8cc9ab52e6d18d52c69d2ff93457dd95f341243b7efb2d7'
+    file_hash = '6b8a7c2f74de1dc3ad18cbb7746910f069b2d56fbc9b2c40180599bf2bc78edf'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           file_hash=file_hash,
