@@ -18,9 +18,8 @@
 Layers blocks definitions.
 """
 
-from tensorflow.keras.layers import (BatchNormalization, ReLU, Conv2D,
-                                     SeparableConv2D, Dense, MaxPool2D,
-                                     AvgPool2D, GlobalAvgPool2D)
+from keras.layers import (BatchNormalization, ReLU, Conv2D, SeparableConv2D,
+                          Dense, MaxPool2D, AvgPool2D, GlobalAvgPool2D)
 
 
 def _add_pooling_layer(x, pooling_type, pool_size, padding, layer_base_name):
@@ -85,7 +84,7 @@ def conv_block(inputs,
             window length will be used for both dimensions.
         add_batchnorm (bool): add a BatchNormalization layer
         add_activation (bool): add a ReLU layer
-        **kwargs: arguments passed to the tf.keras.Conv2D layer, such as
+        **kwargs: arguments passed to the keras.Conv2D layer, such as
             strides, padding, use_bias, weight_regularizer, etc.
 
     Returns:
@@ -143,7 +142,7 @@ def separable_conv_block(inputs,
             window length will be used for both dimensions.
         add_batchnorm (bool): add a BatchNormalization layer
         add_activation (bool): add a ReLU layer
-        **kwargs: arguments passed to the tf.keras.SeparableConv2D layer,
+        **kwargs: arguments passed to the keras.SeparableConv2D layer,
             such as strides, padding, use_bias, etc.
 
     Returns:
