@@ -18,10 +18,10 @@
 Training script for MNIST models.
 """
 
-from tensorflow.keras.datasets import mnist
-from tensorflow.keras.optimizers import Adam
-from tensorflow.keras.metrics import SparseCategoricalAccuracy
-from tensorflow.keras.losses import SparseCategoricalCrossentropy
+from keras.datasets import mnist
+from keras.optimizer_v2.adam import Adam
+from keras.metrics import SparseCategoricalAccuracy
+from keras.losses import SparseCategoricalCrossentropy
 
 from cnn2snn import load_quantized_model, convert
 
@@ -54,8 +54,8 @@ def train_model(model, teacher_model, x_train, y_train, batch_size, epochs):
     """ Trains the model.
 
     Args:
-        model (tf.keras.Model): the model to train
-        teacher_model (tf.keras.Model): the teacher model used for the Knowledge
+        model (keras.Model): the model to train
+        teacher_model (keras.Model): the teacher model used for the Knowledge
             distillation training
         x_train (numpy.ndarray): train data
         y_train (numpy.ndarray): train labels
@@ -82,7 +82,7 @@ def train_model_classical(model, x_train, y_train, batch_size, epochs):
     """ Trains the model without the distillation.
 
     Args:
-        model (tf.keras.Model): the model to train
+        model (keras.Model): the model to train
         x_train (numpy.ndarray): train data
         y_train (numpy.ndarray): train labels
         batch_size (int): the batch size
