@@ -21,7 +21,8 @@ TSE and MLP model definitions.
 import numpy as np
 import tensorflow as tf
 
-from tensorflow.keras.layers import Input, Activation, Reshape, Flatten
+from keras.layers import Input, Activation, Reshape, Flatten
+from keras.feature_column.dense_features_v2 import DenseFeatures
 
 from ..layer_blocks import dense_block
 
@@ -87,7 +88,7 @@ def create_tse(numerical_columns, categorical_columns, units):
             cat_col, embedding_size)
         feature_columns.append(embedding_col)
 
-    feature_layer = tf.keras.layers.DenseFeatures(feature_columns)
+    feature_layer = DenseFeatures(feature_columns)
     feature_layer_outputs = feature_layer(feature_layer_inputs)
 
     x = dense_block(feature_layer_outputs,
