@@ -18,10 +18,9 @@
 VGG model definition for UTKFace regression.
 """
 
-from tensorflow.keras import Model
-from tensorflow.keras.layers import Dropout, Flatten, Input
-from tensorflow.keras.layers.experimental.preprocessing import Rescaling
-from tensorflow.keras.utils import get_file
+from keras import Model
+from keras.layers import Dropout, Flatten, Input, Rescaling
+from keras.utils.data_utils import get_file
 
 from cnn2snn import load_quantized_model, quantize
 
@@ -62,7 +61,7 @@ def vgg_utk_face(input_shape=(32, 32, 3),
             the scale factor is an integer used as a divider.
 
     Returns:
-        tf.keras.Model: a Keras model for VGG/UTKFace
+        keras.Model: a Keras model for VGG/UTKFace
     """
     # Overrides input weight quantization if None
     if input_weight_quantization is None:
@@ -155,7 +154,7 @@ def vgg_utk_face_pretrained():
     UTK Face dataset.
 
     Returns:
-        tf.keras.Model: a Keras Model instance.
+        keras.Model: a Keras Model instance.
 
     """
     model_name = 'vgg_utk_face_iq8_wq2_aq2.h5'
